/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { type FluidClientVersion, type ICodecFamily, type ICodecOptions, type IJsonCodec } from "../../codec/index.js";
import { type TreeStoredSchema } from "../../core/index.js";
import { type JsonCompatible } from "../../util/index.js";
/**
 * Versions for the codec that encodes an in-memory representation of a stored schema {@link TreeStoredSchema} into a persisted format (or decodes it in the opposite direction).
 */
export declare enum SchemaCodecVersion {
    v1 = 1
}
/**
 * Convert a FluidClientVersion to a SchemaCodecVersion.
 * @param clientVersion - The FluidClientVersion to convert.
 * @returns The SchemaCodecVersion that corresponds to the provided FluidClientVersion.
 */
export declare function clientVersionToSchemaVersion(clientVersion: FluidClientVersion): SchemaCodecVersion;
/**
 * Create a schema codec.
 * @param options - Specifies common codec options, including which `validator` to use.
 * @param writeVersion - The schema write version.
 * @returns The composed codec.
 *
 * @privateRemarks We should consider using the Shared Tree format version instead as it may be more valuable for application authors than the schema version.
 */
export declare function makeSchemaCodec(options: ICodecOptions, writeVersion: SchemaCodecVersion): IJsonCodec<TreeStoredSchema>;
/**
 * Create a family of schema codecs.
 * @param options - Specifies common codec options, including which `validator` to use.
 * @returns The composed codec family.
 */
export declare function makeSchemaCodecs(options: ICodecOptions): ICodecFamily<TreeStoredSchema>;
/**
 * Encode an in-memory TreeStoredSchema into the specified format version.
 * @param repo - The in-memory schema.
 * @param version - The schema write version.
 * @returns The encoded schema.
 */
export declare function encodeRepo(repo: TreeStoredSchema, version: SchemaCodecVersion): JsonCompatible;
//# sourceMappingURL=codec.d.ts.map